part of polarizelab.ui;

class Button extends StatefulWidget {
  final Color color;
  final String text;
  final Function onPressed;
  final bool enabled;
  final bool busy;
  final Color textColor;
  final double width;
  final double height;
  final bool visible;
  final String busyText;
  final double minWidth;
  final double cornerRadius;
  final Color disabledColor;
  final double elevation;
  Button(
      {@required this.text,
      @required this.onPressed,
      this.color,
      this.enabled = true,
      this.busy = false,
      this.textColor,
      this.width = double.maxFinite,
      this.minWidth = double.minPositive,
      this.height = 40,
      this.visible = true,
      this.busyText = "Loading...",
      this.cornerRadius = 2,
      this.disabledColor = Colors.grey,
      this.elevation = 16});
  @override
  State<StatefulWidget> createState() {
    return _ButtonState();
  }
}

class _ButtonState extends State<Button> {
  @override
  Widget build(BuildContext context) {
    return AnimatedContainer(
      duration: Duration(milliseconds: 200),
      child: widget.visible
          ? FlatButton(
              shape: RoundedRectangleBorder(
                  borderRadius:
                      BorderRadius.circular(this.widget.cornerRadius)),
              onPressed: widget.enabled ? widget.onPressed : null,
              disabledColor: widget.disabledColor.withAlpha(0x80),
              textColor:
                  widget.textColor ?? Theme.of(context).textTheme.button.color,
              child: Text(widget.busy ? widget.busyText : widget.text),
              color: widget.color ?? Theme.of(context).buttonColor,
            )
          : Container(),
      decoration: BoxDecoration(
          boxShadow: widget.enabled && widget.visible && widget.elevation > 0
              ? <BoxShadow>[
                  BoxShadow(
                    color: (widget.color ?? Theme.of(context).buttonColor)
                        .withAlpha(0x50),
                    blurRadius: widget.elevation,
                  )
                ]
              : []),
      constraints: BoxConstraints(
          maxWidth: widget.width,
          minHeight: widget.height,
          minWidth: widget.minWidth),
    );
  }
}
