part of polarizelab.ui;

class SquareButton extends StatelessWidget {
  final Icon icon;
  final double size;
  final Function onPressed;
  final Color color;
  final bool enabled;
  final bool busy;
  final bool visible;
  final bool hasShadow;
  final double radius;
  final double elevation;
  final String text;
  final Color shadowColor;
  SquareButton(
      {@required this.icon,
      @required this.onPressed,
      this.size = 48,
      this.color,
      this.busy = false,
      this.enabled = true,
      this.visible = true,
      this.hasShadow = true,
      this.radius = 4,
      this.elevation = 16,
      this.text = "",
      this.shadowColor = Colors.grey});
  @override
  Widget build(BuildContext context) {
    return InkWell(
      child: Container(
        decoration: BoxDecoration(
            color: color ?? Theme.of(context).buttonColor,
            borderRadius: BorderRadius.all(Radius.circular(radius)),
            boxShadow: visible && enabled && hasShadow
                ? <BoxShadow>[
                    BoxShadow(
                      color: shadowColor.withAlpha(0x80),
                      blurRadius: elevation,
                    )
                  ]
                : []),
        constraints: BoxConstraints(
            maxHeight: size, maxWidth: size, minHeight: size, minWidth: size),
        child: ClipRRect(
          borderRadius: BorderRadius.circular(radius),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              icon,
              text != ""
                  ? Padding(
                      child: Text(
                        text,
                        style: Theme.of(context).textTheme.caption,
                      ),
                      padding: EdgeInsets.only(top: 16),
                    )
                  : Container()
            ],
          ),
        ),
      ),
      onTap: enabled ? onPressed : null,
    );
  }
}
